@@ -279,6 +279,9 @@ class Personnel(Base):
     # Домашний телефон
     home_phone = Column('personal_home_phone', String(50))
 
+    # Дата начала работы в ВУЗе
+    employment_date = Column('personal_employment_date', DateTime)
+
     # Пол
     sex = Column('personal_sex', Integer)
 
@@ -406,6 +409,40 @@ class OfficeRegistratorFacultyLink(Base):
         return f'{self.office_registrator}: {self.faculty}'
 
 
+class ChairHead(Base):
+    """
+    Заведующий кафедрой
+    """
+    __tablename__ = 'univer_head_chair'
+
+    # Идентификатор
+    id = Column('head_chair_id', Integer, primary_key=True)
+
+    # Сотрудник
+    personnel_id = Column('personal_id', ForeignKey(
+        'univer_personal.personal_id'))
+    personnel = relationship('Personnel')
+
+    # Кафедра
+    chair_id = Column(ForeignKey('univer_chair.chair_id'))
+    chair = relationship('Chair')
+
+    # Дата начала
+    start_date = Column('head_chair_start_date', DateTime)
+
+    # Дата окончания
+    end_date = Column('head_chair_end_date', DateTime)
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<ChairHead {} (id={} status={})'.format(self, self.id, self.status)
+
+    def __str__(self):
+        return f'{self.personnel}: {self.chair}'
+
+
 class Dean(Base):
     """
     Модель "Декан"
@@ -519,4 +556,4 @@ class AdviserStudent(Base):
         return '<AdviserStudent {}>'.format(self)
 
     def __str__(self):
-        return f'{adviser}: {student}'
+        return f'{self.adviser}: {self.student}'
